@@ -6,19 +6,20 @@ from uuid import uuid4, UUID
 import grpc
 from preseem.preseem_model import BaseModelObject
 
+
 class FakePreseemModel:
-    _companies = {} # company_uuid to Company object
+    _companies = {}  # company_uuid to Company object
     _elements = {}  # company_uuid to {element_uuid to Element object}
     _packages = {}  # company_uuid to {package_uuid to Package object}
-    _sites = {}     # company_uuid to {site_uuid to Site object}
-    _elem_disc = {} # company_uuid to {uuid to ElementDiscovery object}
+    _sites = {}  # company_uuid to {site_uuid to Site object}
+    _elem_disc = {}  # company_uuid to {uuid to ElementDiscovery object}
 
     def _new_attrs():
         """Generate attributes for a new preseem-model object."""
         now = time.time()
         uuid = uuid4()
         return {
-            'id': uuid.int & (1<<64)-1,
+            'id': uuid.int & (1 << 64) - 1,
             'uuid': uuid.bytes,
             'created_at': now,
             'updated_at': now,
@@ -56,15 +57,16 @@ class FakePreseemModel:
                 sites = FakePreseemModel._sites[company_uuid] = {}
             sites[obj.uuid] = obj
 
-
     """Fake preseem model that implements the python API."""
+
     class Company(BaseModelObject):
+
         @classmethod
         async def Create(cls, **kwargs):
             obj = cls(**FakePreseemModel._new_attrs(),
-                    name=kwargs.get('name') or '',
-                    parent_uuid=kwargs.get('parent_uuid'),
-                    old_id=kwargs.get('old_id'))
+                      name=kwargs.get('name') or '',
+                      parent_uuid=kwargs.get('parent_uuid'),
+                      old_id=kwargs.get('old_id'))
             FakePreseemModel._companies[obj.uuid] = obj
             return copy.deepcopy(obj)
 
@@ -78,7 +80,9 @@ class FakePreseemModel:
         async def GetByOldId(cls, **kwargs):
             old_id = kwargs.get('old_id')
             assert old_id
-            companies = [x for x in FakePreseemModel._companies.values() if x.old_id == old_id]
+            companies = [
+                x for x in FakePreseemModel._companies.values() if x.old_id == old_id
+            ]
             assert len(companies) < 2
             if companies:
                 return copy.deepcopy(companies[0])
@@ -88,26 +92,26 @@ class FakePreseemModel:
         async def List(cls, **kwargs):
             return [copy.deepcopy(x) for x in FakePreseemModel._companies.values()]
 
-
     class ElementDiscovery(BaseModelObject):
         pass
 
     class Element(BaseModelObject):
+
         @classmethod
         async def Create(cls, **kwargs):
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             company = FakePreseemModel._companies[company_uuid]
             obj = cls(**FakePreseemModel._new_attrs(),
-                    company_uuid=company.uuid,
-                    name=kwargs.get('name'),
-                    serial_number=kwargs.get('serial_number'),
-                    system_mac_address=kwargs.get('system_mac_address'),
-                    imsi=kwargs.get('imsi'),
-                    management_ip=kwargs.get('management_ip'),
-                    site_uuid=kwargs.get('site_uuid'),
-                    status=kwargs.get('status') or 0,
-                    poller_hash=kwargs.get('poller_hash'))
+                      company_uuid=company.uuid,
+                      name=kwargs.get('name'),
+                      serial_number=kwargs.get('serial_number'),
+                      system_mac_address=kwargs.get('system_mac_address'),
+                      imsi=kwargs.get('imsi'),
+                      management_ip=kwargs.get('management_ip'),
+                      site_uuid=kwargs.get('site_uuid'),
+                      status=kwargs.get('status') or 0,
+                      poller_hash=kwargs.get('poller_hash'))
             elems = FakePreseemModel._elements.get(company.uuid)
             if elems is None:
                 elems = FakePreseemModel._elements[company_uuid] = {}
@@ -119,7 +123,10 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._elements.get(company_uuid) or {}).values()]
+            return [
+                copy.deepcopy(x)
+                for x in (FakePreseemModel._elements.get(company_uuid) or {}).values()
+            ]
 
         @classmethod
         async def Delete(cls, **kwargs):
@@ -151,16 +158,17 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             company = FakePreseemModel._companies[company_uuid]
-            obj = FakePreseemModel.ElementDiscovery(**FakePreseemModel._new_attrs(),
-                    company_uuid=company.uuid,
-                    name=kwargs.get('name'),
-                    management_ip=kwargs.get('management_ip'),
-                    site_uuid=kwargs.get('site_uuid'),
-                    source=kwargs.get('source'),
-                    source_id=kwargs.get('source_id'),
-                    intent_role_uuid=kwargs.get('intent_role_uuid'),
-                    element_uuid=kwargs.get('element_uuid'),
-                    status=kwargs.get('status'))
+            obj = FakePreseemModel.ElementDiscovery(
+                **FakePreseemModel._new_attrs(),
+                company_uuid=company.uuid,
+                name=kwargs.get('name'),
+                management_ip=kwargs.get('management_ip'),
+                site_uuid=kwargs.get('site_uuid'),
+                source=kwargs.get('source'),
+                source_id=kwargs.get('source_id'),
+                intent_role_uuid=kwargs.get('intent_role_uuid'),
+                element_uuid=kwargs.get('element_uuid'),
+                status=kwargs.get('status'))
             discs = FakePreseemModel._elem_disc.get(company.uuid)
             if discs is None:
                 discs = FakePreseemModel._elem_disc[company_uuid] = {}
@@ -173,7 +181,11 @@ class FakePreseemModel:
             intent_role_uuid = kwargs.get('intent_role_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._elem_disc.get(company_uuid) or {}).values() if not intent_role_uuid or intent_role_uuid == x.intent_role_uuid]
+            return [
+                copy.deepcopy(x)
+                for x in (FakePreseemModel._elem_disc.get(company_uuid) or {}).values()
+                if not intent_role_uuid or intent_role_uuid == x.intent_role_uuid
+            ]
 
         @classmethod
         async def DeleteElementDiscovery(cls, **kwargs):
@@ -189,7 +201,7 @@ class FakePreseemModel:
         async def UpdateElementDiscovery(cls, **kwargs):
             company_uuid = kwargs.get('company_uuid')
             uuid = kwargs.get('uuid')
-            discs= FakePreseemModel._elem_disc[company_uuid]
+            discs = FakePreseemModel._elem_disc[company_uuid]
             if discs:
                 disc = discs.get(uuid)
                 for attr, val in kwargs.items():
@@ -202,20 +214,20 @@ class FakePreseemModel:
                             disc.updated_at = time.time()
                         setattr(disc, attr, val)
 
-
     class Package(BaseModelObject):
+
         @classmethod
         async def Create(cls, **kwargs):
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             company = FakePreseemModel._companies[company_uuid]
             obj = cls(**FakePreseemModel._new_attrs(),
-                    company_uuid=company.uuid,
-                    name=kwargs.get('name') or '',
-                    source=kwargs.get('source'),
-                    source_id=kwargs.get('source_id'),
-                    download_rate=kwargs.get('download_rate'),
-                    upload_rate=kwargs.get('upload_rate'))
+                      company_uuid=company.uuid,
+                      name=kwargs.get('name') or '',
+                      source=kwargs.get('source'),
+                      source_id=kwargs.get('source_id'),
+                      download_rate=kwargs.get('download_rate'),
+                      upload_rate=kwargs.get('upload_rate'))
             packages = FakePreseemModel._packages.get(company.uuid)
             if packages is None:
                 packages = FakePreseemModel._packages[company_uuid] = {}
@@ -227,7 +239,10 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._packages.get(company_uuid) or {}).values()]
+            return [
+                copy.deepcopy(x)
+                for x in (FakePreseemModel._packages.get(company_uuid) or {}).values()
+            ]
 
         @classmethod
         async def Delete(cls, **kwargs):
@@ -256,16 +271,16 @@ class FakePreseemModel:
                             package.updated_at = time.time()
                         setattr(package, attr, val)
 
-
     class Site(BaseModelObject):
+
         @classmethod
         async def Create(cls, **kwargs):
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             company = FakePreseemModel._companies[company_uuid]
             obj = cls(**FakePreseemModel._new_attrs(),
-                    company_uuid=company.uuid,
-                    name=kwargs.get('name') or '')
+                      company_uuid=company.uuid,
+                      name=kwargs.get('name') or '')
             sites = FakePreseemModel._sites.get(company.uuid)
             if sites is None:
                 sites = FakePreseemModel._sites[company_uuid] = {}
@@ -277,7 +292,10 @@ class FakePreseemModel:
             company_uuid = kwargs.get('company_uuid')
             assert company_uuid
             # the real impl returns empty list if the company doesn't exist
-            return [copy.deepcopy(x) for x in (FakePreseemModel._sites.get(company_uuid) or {}).values()]
+            return [
+                copy.deepcopy(x)
+                for x in (FakePreseemModel._sites.get(company_uuid) or {}).values()
+            ]
 
         @classmethod
         async def Delete(cls, **kwargs):
