@@ -9,13 +9,19 @@ import pytricia
 from preseem_grpc_model import network_metadata_pb2
 from preseem.grpc_client import PreseemGrpcClient
 
-NetworkMetadataEntity = namedtuple('NetworkMetadataEntity', ('network_prefix', 'start', 'attributes'))
-NetworkMetadataReference = namedtuple('NetworkMetadataReference', ('type', 'value', 'attributes'))
+NetworkMetadataEntity = namedtuple('NetworkMetadataEntity',
+                                   ('network_prefix', 'start', 'attributes'))
+NetworkMetadataReference = namedtuple('NetworkMetadataReference',
+                                      ('type', 'value', 'attributes'))
 NetworkMetadataIndex = namedtuple('NetworkMetadataIndex', ('type', 'attribute'))
 
+
 class NetworkMetadataClient(PreseemGrpcClient):
+
     def __init__(self, api_key, host=None, port=None, beta=None):
-        super().__init__(api_key, host or 'nmapi{}.preseem.com'.format('-beta' if beta else ''), port)
+        super().__init__(api_key, host
+                         or 'nmapi{}.preseem.com'.format('-beta' if beta else ''), port)
+
 
 def ip_sort_key(x):
     """Sort key for listing IP address strings."""
@@ -24,8 +30,9 @@ def ip_sort_key(x):
     except OSError:
         return bytes(0)
 
+
 def _resolve_refs(refs, attrs):
-    "Helper function to resolve reference attributes."""
+    "Helper function to resolve reference attributes." ""
     for t, v in list(attrs.items()):
         if isinstance(v, Reference):
             refmap = refs.get(t)
@@ -35,6 +42,7 @@ def _resolve_refs(refs, attrs):
                     attrs.update(_resolve_refs(refs, ref.attributes))
     return attrs
 
+
 def _diff(src, dst, refs_by_type=False):
     """Helper function to return operations to make dst like src"""
     adds = []
@@ -60,14 +68,17 @@ def _diff(src, dst, refs_by_type=False):
             mods.append(sobj)
     return adds, dels, mods
 
+
 class Reference(str):
     """This is used to hint to the GRPC code that it should create a ref"""
     pass
 
+
 class uint64(int):
     """This is used to hint to the GRPC code that it should create a uint"""
     pass
 
+
 def _attrs_to_dict(attrs):
     result = {}
     for attr, data in attrs.items():
@@ -86,6 +97,7 @@ def _attrs_to_dict(attrs):
         result[attr] = val
     return result
 
+
 def _nm_set_attrs(nm_attrs, py_attrs):
     for t, v in py_attrs.items():
         if v is None:
@@ -117,18 +129,24 @@ def _nm_set_attrs(nm_attrs, py_attrs):
 
 
 class PreseemNetworkMetadataModel(object):
-    def __init__(self, client, company_id=None, cbk=None, refs_by_type=None, indexes=None):
+
+    def __init__(self,
+                 client,
+                 company_id=None,
+                 cbk=None,
+                 refs_by_type=None,
+                 indexes=None):
         """
         Pass in refs_by_type=True to use the newer API where the "refs"
         attribute is {type: {id: obj}}.  Default is {(type, id): obj}.
         Indexes are specified here as a list of NetworkMetadataIndex.
         """
         self._client = client
-        self.company_id = company_id    # used for multi-company keys
-        self._cbk = cbk                 # optional callback for updates
+        self.company_id = company_id  # used for multi-company keys
+        self._cbk = cbk  # optional callback for updates
         self.refs_by_type = refs_by_type
-        self.refs = {}                  # public: current references
-        self.nms = {}                   # public: current entities
+        self.refs = {}  # public: current references
+        self.nms = {}  # public: current entities
         self.pt4 = pytricia.PyTricia(32)
         self.syn = None  # dict of GRPC objects we receive in synchronize state
         self.nm_syn = None
@@ -152,7 +170,6 @@ class PreseemNetworkMetadataModel(object):
             self._ref_sub_task.cancel()
             self._ref_sub_task = None
 
-
     async def handle_ent_update(self, msg, syn=False):
         if syn:
             self.nm_syn = {}
@@ -164,7 +181,7 @@ class PreseemNetworkMetadataModel(object):
                     try:
                         self.pt4[ip] = nm
                     except Exception as err:
-                        logging.warning('Error setting nm entity %s: %s', ip, err)
+                        logging.info('Error setting nm entity %s: %s', ip, err)
                         continue
             self.nm_syn = None
             if self._cbk:
@@ -190,7 +207,8 @@ class PreseemNetworkMetadataModel(object):
                     try:
                         self.pt4[nm.network_prefix] = nm
                     except Exception as err:
-                        logging.warning('Error setting nm entity %s: %s', nm.network_prefix, err)
+                        logging.info('Error setting nm entity %s: %s',
+                                        nm.network_prefix, err)
                         del self.nm_syn[nm.network_prefix]
         elif msg.action == network_metadata_pb2.NetworkMetadataEntityAction.DELETE:
             nm = self._make_nm(msg.entity)
@@ -226,14 +244,18 @@ class PreseemNetworkMetadataModel(object):
             self.start_load = asyncio.get_event_loop().time()
         if msg.action == network_metadata_pb2.NetworkMetadataReferenceEntityAction.LOADED:
             self.refs = self.syn
-            logging.info('Loaded nm refs in %s seconds', asyncio.get_event_loop().time() - self.start_load or 0)
+            logging.info('Loaded nm refs in %s seconds',
+                         asyncio.get_event_loop().time() - self.start_load or 0)
             self.start_load = None
             if self.refs_by_type:
                 for it, index in self._index.items():
                     for ia, ir in index.items():
                         ir.clear()
                         if ia == '_LOWER':  # lowercase value index
-                            ir[None] = {n.lower(): r for n, r in (self.refs.get(it) or {}).items()}
+                            ir[None] = {
+                                n.lower(): r
+                                for n, r in (self.refs.get(it) or {}).items()
+                            }
                             continue
                         for ref in (self.refs.get(it) or {}).values():
                             attr = ref.attributes.get(ia)
@@ -256,7 +278,8 @@ class PreseemNetworkMetadataModel(object):
             async with self._refs_loaded:
                 self._refs_loaded.notify()
         elif msg.action == network_metadata_pb2.NetworkMetadataReferenceEntityAction.SET:
-            ref = NetworkMetadataReference(msg.entity.type, msg.entity.value, _attrs_to_dict(msg.entity.attributes))
+            ref = NetworkMetadataReference(msg.entity.type, msg.entity.value,
+                                           _attrs_to_dict(msg.entity.attributes))
             if self.syn is None:
                 if self.refs_by_type:
                     refs = self.refs.get(ref.type)
@@ -302,7 +325,8 @@ class PreseemNetworkMetadataModel(object):
                 else:
                     self.syn[(ref.type, ref.value)] = ref
         elif msg.action == network_metadata_pb2.NetworkMetadataReferenceEntityAction.DELETE:
-            ref = NetworkMetadataReference(msg.entity.type, msg.entity.value, _attrs_to_dict(msg.entity.attributes))
+            ref = NetworkMetadataReference(msg.entity.type, msg.entity.value,
+                                           _attrs_to_dict(msg.entity.attributes))
             try:
                 # use the saved ref so we have its attributes
                 if self.refs_by_type:
@@ -366,7 +390,8 @@ class PreseemNetworkMetadataModel(object):
         assert isinstance(entity, NetworkMetadataEntity)
         ts = network_metadata_pb2.google_dot_protobuf_dot_timestamp__pb2.Timestamp()
         ts.FromNanoseconds(int(entity.start * 1000000000))
-        obj = network_metadata_pb2.NetworkMetadataEntity(address_space='default', network_prefix=entity.network_prefix, start=ts)
+        obj = network_metadata_pb2.NetworkMetadataEntity(
+            address_space='default', network_prefix=entity.network_prefix, start=ts)
         _nm_set_attrs(obj.attributes, entity.attributes)
         await self._client.nm_set(obj, company_id=self.company_id)
 
@@ -374,7 +399,8 @@ class PreseemNetworkMetadataModel(object):
         assert isinstance(entity, NetworkMetadataEntity)
         ts = network_metadata_pb2.google_dot_protobuf_dot_timestamp__pb2.Timestamp()
         ts.FromNanoseconds(int(entity.start * 1000000000))
-        obj = network_metadata_pb2.NetworkMetadataEntity(address_space='default', network_prefix=entity.network_prefix, start=ts)
+        obj = network_metadata_pb2.NetworkMetadataEntity(
+            address_space='default', network_prefix=entity.network_prefix, start=ts)
         _nm_set_attrs(obj.attributes, entity.attributes)
         await self._client.nm_del(obj, company_id=self.company_id)
 
@@ -388,13 +414,15 @@ class PreseemNetworkMetadataModel(object):
 
     async def set_ref(self, ref):
         assert isinstance(ref, NetworkMetadataReference)
-        obj = network_metadata_pb2.NetworkMetadataReferenceEntity(type=ref.type, value=ref.value)
+        obj = network_metadata_pb2.NetworkMetadataReferenceEntity(type=ref.type,
+                                                                  value=ref.value)
         _nm_set_attrs(obj.attributes, ref.attributes)
         await self._client.nm_ref_set(obj, company_id=self.company_id)
 
     async def del_ref(self, ref):
         assert isinstance(ref, NetworkMetadataReference)
-        obj = network_metadata_pb2.NetworkMetadataReferenceEntity(type=ref.type, value=ref.value)
+        obj = network_metadata_pb2.NetworkMetadataReferenceEntity(type=ref.type,
+                                                                  value=ref.value)
         await self._client.nm_ref_del(obj, company_id=self.company_id)
 
     async def update(self):
@@ -404,7 +432,8 @@ class PreseemNetworkMetadataModel(object):
             # Setup a subscription to get the initial elements and keep in sync
             async with self._refs_lock:
                 if self._ref_sub_task is None:
-                    cor = self._client.nm_ref_subscribe(self.handle_ref_update, company_id=self.company_id)
+                    cor = self._client.nm_ref_subscribe(self.handle_ref_update,
+                                                        company_id=self.company_id)
                     task = asyncio.get_event_loop().create_task(cor)
                     async with self._refs_loaded:
                         await self._refs_loaded.wait()
@@ -412,7 +441,8 @@ class PreseemNetworkMetadataModel(object):
         if self._ent_sub_task is None:
             async with self._ents_lock:
                 if self._ent_sub_task is None:
-                    cor = self._client.nm_ent_subscribe(self.handle_ent_update, company_id=self.company_id)
+                    cor = self._client.nm_ent_subscribe(self.handle_ent_update,
+                                                        company_id=self.company_id)
                     task = asyncio.get_event_loop().create_task(cor)
                     async with self._ents_loaded:
                         await self._ents_loaded.wait()
@@ -420,9 +450,11 @@ class PreseemNetworkMetadataModel(object):
 
     async def copy(self, dst_model):
         """Perform operations to make a destination model the same as this."""
+
         async def copy_refs():
             adds, dels, mods = _diff(self.refs, dst_model.refs, self.refs_by_type)
-            logging.info('refs: {} adds, {} dels, {} mods'.format(len(adds), len(dels), len(mods)))
+            logging.info('refs: {} adds, {} dels, {} mods'.format(
+                len(adds), len(dels), len(mods)))
             for obj in adds:
                 await dst_model.set_ref(obj)
             for obj in dels:
@@ -432,7 +464,8 @@ class PreseemNetworkMetadataModel(object):
 
         async def copy_nms():
             adds, dels, mods = _diff(self.nms, dst_model.nms)
-            logging.info('ipas: {} adds, {} dels, {} mods'.format(len(adds), len(dels), len(mods)))
+            logging.info('ipas: {} adds, {} dels, {} mods'.format(
+                len(adds), len(dels), len(mods)))
             for obj in adds:
                 await dst_model.set_nm(obj)
             for obj in dels:
@@ -445,6 +478,7 @@ class PreseemNetworkMetadataModel(object):
 
     def diff(self, rhs_model):
         """Compare this model to another one."""
+
         def resolve_refs(refs, attrs):
             """Resolve references.  return the combined attribute map."""
             result = {}
@@ -465,7 +499,8 @@ class PreseemNetworkMetadataModel(object):
             return result
 
         diffs = []
-        for key in sorted(set(list(self.nms.keys()) + list(rhs_model.nms.keys())), key=ip_sort_key):
+        for key in sorted(set(list(self.nms.keys()) + list(rhs_model.nms.keys())),
+                          key=ip_sort_key):
             lobj = self.nms.get(key)
             robj = rhs_model.nms.get(key)
             if lobj:
@@ -477,7 +512,9 @@ class PreseemNetworkMetadataModel(object):
             elif lobj is None and rattrs:
                 diffs.append((key, None, rattrs))
             elif robj and lobj and lattrs != rattrs:
-                diffs.append((key,
-                              {x: y for x, y in lattrs.items() if rattrs.get(x) != y},
-                              {x: y for x, y in rattrs.items() if lattrs.get(x) != y}))
+                diffs.append(
+                    (key, {x: y
+                           for x, y in lattrs.items() if rattrs.get(x) != y},
+                     {x: y
+                      for x, y in rattrs.items() if lattrs.get(x) != y}))
         return diffs
