@@ -74,8 +74,8 @@ async def sync_preseem_model(preseem_model,
 
     async with sync_lock:
         model_discs, model_sites, model_packages = await asyncio.gather(
-            preseem_model.Element.ListElementDiscovery(
-                company_uuid=company_uuid, intent_role_uuid=role.bytes),
+            preseem_model.Element.ListElementDiscovery(company_uuid=company_uuid,
+                                                       intent_role_uuid=role.bytes),
             preseem_model.Site.List(company_uuid=company_uuid),
             preseem_model.Package.List(company_uuid=company_uuid))
 
@@ -112,23 +112,20 @@ async def sync_preseem_model(preseem_model,
                 if not site:
                     new_sites.add(item.site)
                 elif site.inactive:
-                    logging.info(
-                        'sync_preseem_model(%s): reactivate site "%s"',
-                        source, item.site)
+                    logging.info('sync_preseem_model(%s): reactivate site "%s"', source,
+                                 item.site)
                     if not noact:
                         await call_and_log_error(
-                            preseem_model.Site.Update(
-                                company_uuid=company_uuid,
-                                uuid=site.uuid,
-                                inactive=False))
+                            preseem_model.Site.Update(company_uuid=company_uuid,
+                                                      uuid=site.uuid,
+                                                      inactive=False))
         if dup_ids:
-            logging.warning('sync_preseem_model(%s): duplicate IDs found: %s',
-                            source, dup_ids)
+            logging.warning('sync_preseem_model(%s): duplicate IDs found: %s', source,
+                            dup_ids)
             raise ValueError(f'duplicate IDs found')
 
         for site_name in new_sites:
-            logging.info('sync_preseem_model(%s): create site "%s"', source,
-                         site_name)
+            logging.info('sync_preseem_model(%s): create site "%s"', source, site_name)
             if not noact:
                 site = site_names[site_name] = await call_and_log_error(
                     preseem_model.Site.Create(company_uuid=company_uuid,
@@ -136,8 +133,7 @@ async def sync_preseem_model(preseem_model,
                 if site:
                     model_sites[site.uuid] = site_names[site_name] = site
 
-        unref_discs = set(
-            [x[0] for x in model_discs.items() if x[1].source == source])
+        unref_discs = set([x[0] for x in model_discs.items() if x[1].source == source])
         uuid_map = {}
         for item in items:
             host = str(ipaddress.ip_address(item.host))  # validate ip address
@@ -146,8 +142,7 @@ async def sync_preseem_model(preseem_model,
             if disc:
                 uuid_map[item.id] = UUID(bytes=disc.uuid)
                 unref_discs.remove(disc.uuid)
-                site = model_sites.get(
-                    disc.site_uuid) if disc.site_uuid else None
+                site = model_sites.get(disc.site_uuid) if disc.site_uuid else None
                 changes = []
                 mods = {}
                 if disc.inactive:
@@ -158,32 +153,29 @@ async def sync_preseem_model(preseem_model,
                     changes.append(f'name: {disc.name} -> {item.name}')
                     mods['name'] = item.name
                 if disc.management_ip != host:
-                    changes.append(
-                        f'management_ip: {disc.management_ip} -> {host}')
+                    changes.append(f'management_ip: {disc.management_ip} -> {host}')
                     mods['management_ip'] = host
                 if site.name != item.site:
                     changes.append(f'site: {site.name} -> {item.site}')
                     mods['site_uuid'] = site_names[item.site].uuid
                 if mods:
-                    logging.info('sync_preseem_model(%s): modify %s (%s)',
-                                 source, item, ','.join(changes))
+                    logging.info('sync_preseem_model(%s): modify %s (%s)', source, item,
+                                 ','.join(changes))
                     if not noact:
                         if nm_model and 'reactivated' in changes and disc.element_uuid:
                             # STM-9823 as part of clearing the element_uuid,
                             # we also need to delete the elem_discovery ref.
                             ref = NetworkMetadataReference('elem_discovery',
-                                str(UUID(bytes=disc.uuid)), {})
+                                                           str(UUID(bytes=disc.uuid)),
+                                                           {})
                             logging.info(' delete reference: %s', ref)
                             await nm_model.del_ref(ref)
                         await call_and_log_error(
                             preseem_model.Element.UpdateElementDiscovery(
-                                company_uuid=company_uuid,
-                                uuid=disc.uuid,
-                                **mods))
+                                company_uuid=company_uuid, uuid=disc.uuid, **mods))
 
             else:
-                logging.info('sync_preseem_model(%s): create %s', source,
-                             item)
+                logging.info('sync_preseem_model(%s): create %s', source, item)
                 if not noact:
                     site_uuid = site_names[item.site].uuid
                     disc = await call_and_log_error(
@@ -209,9 +201,7 @@ async def sync_preseem_model(preseem_model,
                 if not noact:
                     await call_and_log_error(
                         preseem_model.Element.UpdateElementDiscovery(
-                            company_uuid=company_uuid,
-                            uuid=disc_uuid,
-                            inactive=True))
+                            company_uuid=company_uuid, uuid=disc_uuid, inactive=True))
 
         if packages is not None:
             assert isinstance(packages, dict)
@@ -223,9 +213,11 @@ async def sync_preseem_model(preseem_model,
                 if bpkg:
                     if not isinstance(bpkg.name, str) or bpkg.name == '':
                         raise ValueError('invalid string value for package name')
-                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int) or bpkg.download_rate < 0):
+                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int)
+                                               or bpkg.download_rate < 0):
                         raise ValueError('invalid value for package down rate')
-                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int) or bpkg.upload_rate < 0):
+                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int)
+                                             or bpkg.upload_rate < 0):
                         raise ValueError('invalid value for package up rate')
                     changes = []
                     mods = {}
@@ -237,28 +229,29 @@ async def sync_preseem_model(preseem_model,
                         changes.append(f'name: {mpkg.name} -> {bpkg.name}')
                         mods['name'] = bpkg.name
                     if mpkg.download_rate != (bpkg.download_rate or None):
-                        changes.append(f'download_rate: {mpkg.download_rate} -> {bpkg.download_rate}')
+                        changes.append(
+                            f'download_rate: {mpkg.download_rate} -> {bpkg.download_rate}'
+                        )
                         mods['download_rate'] = bpkg.download_rate or None
                     if mpkg.upload_rate != (bpkg.upload_rate or None):
-                        changes.append(f'upload_rate: {mpkg.upload_rate} -> {bpkg.upload_rate}')
+                        changes.append(
+                            f'upload_rate: {mpkg.upload_rate} -> {bpkg.upload_rate}')
                         mods['upload_rate'] = bpkg.upload_rate or None
                     if mods:
-                        logging.info('sync_packages(%s): modify %s (%s)',
-                                     source, mpkg, ', '.join(changes))
-                        await preseem_model.Package.Update(
-                            company_uuid=company_uuid,
-                            uuid=mpkg.uuid,
-                            **mods)
+                        logging.info('sync_packages(%s): modify %s (%s)', source, mpkg,
+                                     ', '.join(changes))
+                        await preseem_model.Package.Update(company_uuid=company_uuid,
+                                                           uuid=mpkg.uuid,
+                                                           **mods)
                 else:
                     if not mpkg.inactive:
-                        logging.info("sync_preseem_model(%s): deactivate package %s", source,
-                                     UUID(bytes=mpkg.uuid))
+                        logging.info("sync_preseem_model(%s): deactivate package %s",
+                                     source, UUID(bytes=mpkg.uuid))
                         if not noact:
                             await call_and_log_error(
-                                preseem_model.Package.Update(
-                                    company_uuid=company_uuid,
-                                    uuid=mpkg.uuid,
-                                    inactive=True))
+                                preseem_model.Package.Update(company_uuid=company_uuid,
+                                                             uuid=mpkg.uuid,
+                                                             inactive=True))
             for pkg_id in new_package_ids:
                 bpkg = packages.get(pkg_id)
                 if bpkg:
@@ -266,9 +259,11 @@ async def sync_preseem_model(preseem_model,
                         raise ValueError('invalid string value for package source_id')
                     if not isinstance(bpkg.name, str) or bpkg.name == '':
                         raise ValueError('invalid string value for package name')
-                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int) or bpkg.download_rate < 0):
+                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int)
+                                               or bpkg.download_rate < 0):
                         raise ValueError('invalid value for package down rate')
-                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int) or bpkg.upload_rate < 0):
+                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int)
+                                             or bpkg.upload_rate < 0):
                         raise ValueError('invalid value for package up rate')
                     logging.info('sync_preseem_model(%s): create %s', source, bpkg)
                     if not noact:
@@ -282,8 +277,7 @@ async def sync_preseem_model(preseem_model,
                                 upload_rate=bpkg.upload_rate or None))
                         if mpkg:
                             uuid = UUID(bytes=mpkg.uuid)
-                            logging.info(
-                                'sync_preseem_model(%s): created Package "%s"',
-                                source, uuid)
+                            logging.info('sync_preseem_model(%s): created Package "%s"',
+                                         source, uuid)
 
         return uuid_map
